Module search

Module search 

Provides the ability to search tuple elements by type.

Check the documentation page of Search for details.

Structs

Complete
Helper type indicates that the search has been completed.
Unused
Helper type indicates that current element is excluded by the search result.
Used
Helper type indicates that current element is included by the search result.

Traits

ConSubseq
Search for contiguous subsequences of tuples.
ConSubseqMapReplace
Replace elements of a specific contiguous subsequence to another sequence that may be of different element types.
Search
Search for an element of a specific type in a tuple.
Subseq
Search for subsequences of tuples.
SubseqMapReplace
Replace elements of a specific subsequence to another sequence that may be of different element types.
TailReplaceable
replace tail elements of the tuple.